ControllerAxisEvent

Trait ControllerAxisEvent 

pub trait ControllerAxisEvent: Sized {
    // Required methods
    fn from_controller_axis_args(
        args: ControllerAxisArgs,
        old_event: &Self,
    ) -> Option<Self>;
    fn controller_axis<U, F>(&self, f: F) -> Option<U>
       where F: FnMut(ControllerAxisArgs) -> U;

    // Provided method
    fn controller_axis_args(&self) -> Option<ControllerAxisArgs> { ... }
}
The position of a controller axis changed.

Required Methods

fn from_controller_axis_args( args: ControllerAxisArgs, old_event: &Self, ) -> Option<Self>

Creates a controller axis event.

Preserves time stamp from original input event, if any.

fn controller_axis<U, F>(&self, f: F) -> Option<U>
where F: FnMut(ControllerAxisArgs) -> U,

Calls closure if this is a controller axis event.

Provided Methods

fn controller_axis_args(&self) -> Option<ControllerAxisArgs>

Returns controller axis arguments.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors